# Generated by Django 5.1.5 on 2025-02-05 13:23

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lastfm', '0008_auto_20180104_1457'),
    ]

    operations = [
        migrations.AlterField(
            model_name='scrobble',
            name='post_time',
            field=models.DateTimeField(blank=True, db_index=True, default=django.utils.timezone.now, help_text='The time the item was originally posted/created on its service.', null=True),
        ),
    ]
