# Generated by Django 3.1.3 on 2020-11-19 12:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("twitter", "0055_re_save_tweets_for_new_html"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="tweet",
            options={"ordering": ["-post_time", "-twitter_id"]},
        ),
        migrations.AddIndex(
            model_name="tweet",
            index=models.Index(
                fields=["user", "post_time", "is_private"],
                name="twitter_twe_user_id_12e113_idx",
            ),
        ),
    ]
