# Generated by Django 1.9.5 on 2016-06-03 13:01

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("twitter", "0038_tweet_retweeted_status_id"),
    ]

    operations = [
        migrations.AddField(
            model_name="media",
            name="tweets",
            field=models.ManyToManyField(to="twitter.Tweet"),
        ),
        migrations.AlterField(
            model_name="media",
            name="tweet",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="temporary_name",
                to="twitter.Tweet",
            ),
        ),
    ]
