# Generated by Django 1.9.5 on 2016-04-28 15:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pinboard", "0019_auto_20160428_1525"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bookmark",
            name="url_hash",
            field=models.CharField(
                db_index=True,
                help_text="Slug in the Bookmark's URL here.",
                max_length=12,
            ),
        ),
    ]
