# Generated by Django 5.1.5 on 2025-02-05 13:18

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pinboard', '0027_alter_bookmarktag_slug'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bookmark',
            name='url',
            field=models.URLField(max_length=1000, validators=[django.core.validators.URLValidator()], verbose_name='URL'),
        ),
        migrations.AlterField(
            model_name='bookmark',
            name='url_hash',
            field=models.CharField(blank=True, db_index=True, help_text="Slug in the Bookmark's local URL.", max_length=12, verbose_name='URL hash'),
        ),
    ]
