# Generated by Django 4.0.3 on 2022-03-23 15:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("flickr", "0027_alter_user_photos_url_alter_user_profile_url"),
    ]

    operations = [
        migrations.AlterField(
            model_name="user",
            name="iconfarm",
            field=models.PositiveIntegerField(default=0),
        ),
    ]
