# Generated by Django 5.1.5 on 2025-02-05 15:12

import taggit.managers
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pinboard', '0029_alter_bookmark_post_time'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bookmark',
            name='tags',
            field=taggit.managers.TaggableManager(blank=True, help_text='Separated by spaces. Private tags start with a period.', through='pinboard.TaggedBookmark', to='pinboard.BookmarkTag', verbose_name='Tags'),
        ),
    ]
