# Generated by Django 4.0.3 on 2022-03-23 14:48

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("taggit", "0004_alter_taggeditem_content_type_alter_taggeditem_tag"),
        ("flickr", "0025_backfill_photo_sizes"),
    ]

    operations = [
        migrations.AlterField(
            model_name="taggedphoto",
            name="content_object",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(app_label)s_%(class)s_items",
                to="flickr.photo",
            ),
        ),
        migrations.AlterField(
            model_name="taggedphoto",
            name="tag",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="%(app_label)s_%(class)s_items",
                to="taggit.tag",
            ),
        ),
    ]
