# Generated by Django 1.9.5 on 2016-06-03 13:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("twitter", "0040_auto_20160603_1302"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="media",
            name="tweet",
        ),
    ]
