# Generated by Django 3.1.3 on 2020-12-23 15:09

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("pinboard", "0024_bookmark_post_year"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bookmarktag",
            name="name",
            field=models.CharField(max_length=100, unique=True, verbose_name="name"),
        ),
        migrations.AlterField(
            model_name="bookmarktag",
            name="slug",
            field=models.SlugField(max_length=100, unique=True, verbose_name="slug"),
        ),
        migrations.AlterField(
            model_name="taggedbookmark",
            name="content_type",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="pinboard_taggedbookmark_tagged_items",
                to="contenttypes.contenttype",
                verbose_name="content type",
            ),
        ),
        migrations.AlterField(
            model_name="taggedbookmark",
            name="object_id",
            field=models.IntegerField(db_index=True, verbose_name="object ID"),
        ),
    ]
