# Generated by Django 4.1 on 2022-11-28 14:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pinboard", "0026_alter_taggedbookmark_content_type_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bookmarktag",
            name="slug",
            field=models.SlugField(
                allow_unicode=True, max_length=100, unique=True, verbose_name="slug"
            ),
        ),
    ]
